@@ -1,8 +1,9 @@
 #!/bin/bash
 type module >& /dev/null || . /mnt/software/Modules/current/init/bash
-module load python/2.7.9-mobs-pbcore
+module load python/3
+module load htslib  # since pysam was built against this
 set -ex
-
+nproc
 
 export PATH=$PWD/build/bin:$PATH
 export PYTHONUSERBASE=$PWD/build
@@ -18,13 +19,15 @@ else
   WHEELHOUSE=/mnt/software/p/python/wheelhouse/develop
 fi
 
-rm -rf   build
+rm -rf build
 mkdir -p build/bin build/lib build/include build/share
-$PIP install --no-compile --find-link $WHEELHOUSE --user -r requirements.txt
-$PIP install --no-compile --find-link $WHEELHOUSE --user -r requirements-dev.txt
-$PIP install --no-compile --find-link $WHEELHOUSE --user -e ./
+$PIP install --user --no-index --find-link $WHEELHOUSE --no-compile -e '.[test]'
+
+pytest --trace-config --collect-only
 
 set +e
 make pylint # way too many errors right now
 set -e
 make test
+
+bash bamboo_wheel.sh
