@@ -1,7 +1,7 @@
 # pbcore/io/dataset/pyxb/_pbsample.py
 # -*- coding: utf-8 -*-
 # PyXB bindings for NM:a7c0866985dba806fe3112e9fbc4707c9f978443
-# Generated 2018-09-28 10:06:49.298232 by PyXB version 1.2.4 using Python 2.7.9.final.0
+# Generated 2020-05-05 09:21:48.249872 by PyXB version 1.2.6 using Python 3.7.3.final.0
 # Namespace http://pacificbiosciences.com/PacBioSampleInfo.xsd [xmlns:pbsample]
 
 from __future__ import unicode_literals
@@ -13,16 +13,19 @@ import pyxb.utils.utility
 import pyxb.utils.domutils
 import sys
 import pyxb.utils.six as _six
-
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:e2ef7b8c-c340-11e8-a616-1803730e031b')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:84ba9ef6-8eec-11ea-9839-005056871a22')
 
 # Version of PyXB used to generate the bindings
-_PyXBVersion = '1.2.4'
+_PyXBVersion = '1.2.6'
 # Generated bindings are not compatible across PyXB versions
 if pyxb.__version__ != _PyXBVersion:
     raise pyxb.PyXBVersionError(_PyXBVersion)
 
+# A holder for module-level binding classes so we can access them from
+# inside class definitions where property names may conflict.
+_module_typeBindings = pyxb.utils.utility.Object()
+
 # Import bindings for namespaces imported into schema
 import pyxb.binding.datatypes
 import _pbbase as _ImportedBinding__pbbase
@@ -83,20 +86,20 @@ class CTD_ANON (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = None
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 96, 2)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 96, 4)
     _ElementMap = {}
     _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.anyType
     
     # Element {http://pacificbiosciences.com/PacBioSampleInfo.xsd}BioSamplePointer uses Python identifier BioSamplePointer
-    __BioSamplePointer = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'BioSamplePointer'), 'BioSamplePointer', '__httppacificbiosciences_comPacBioSampleInfo_xsd_CTD_ANON_httppacificbiosciences_comPacBioSampleInfo_xsdBioSamplePointer', False, pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 103, 5), )
+    __BioSamplePointer = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'BioSamplePointer'), 'BioSamplePointer', '__httppacificbiosciences_comPacBioSampleInfo_xsd_CTD_ANON_httppacificbiosciences_comPacBioSampleInfo_xsdBioSamplePointer', False, pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 103, 10), )
 
     
     BioSamplePointer = property(__BioSamplePointer.value, __BioSamplePointer.set, None, 'Pointer to a single biological sample')
 
     
     # Element {http://pacificbiosciences.com/PacBioSampleInfo.xsd}BarcodedSamplePointers uses Python identifier BarcodedSamplePointers
-    __BarcodedSamplePointers = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'BarcodedSamplePointers'), 'BarcodedSamplePointers', '__httppacificbiosciences_comPacBioSampleInfo_xsd_CTD_ANON_httppacificbiosciences_comPacBioSampleInfo_xsdBarcodedSamplePointers', False, pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 112, 1), )
+    __BarcodedSamplePointers = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'BarcodedSamplePointers'), 'BarcodedSamplePointers', '__httppacificbiosciences_comPacBioSampleInfo_xsd_CTD_ANON_httppacificbiosciences_comPacBioSampleInfo_xsdBarcodedSamplePointers', False, pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 112, 2), )
 
     
     BarcodedSamplePointers = property(__BarcodedSamplePointers.value, __BarcodedSamplePointers.set, None, 'Back references to other BarcodedSampleType object UniqueIds which utilize this sample')
@@ -108,7 +111,7 @@ class CTD_ANON (pyxb.binding.basis.complexTypeDefinition):
     _AttributeMap.update({
         
     })
-
+_module_typeBindings.CTD_ANON = CTD_ANON
 
 
 # Complex type [anonymous] with content type ELEMENT_ONLY
@@ -118,13 +121,13 @@ class CTD_ANON_ (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = None
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 116, 2)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 116, 4)
     _ElementMap = {}
     _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.anyType
     
     # Element {http://pacificbiosciences.com/PacBioSampleInfo.xsd}BarcodedSamplePointer uses Python identifier BarcodedSamplePointer
-    __BarcodedSamplePointer = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'BarcodedSamplePointer'), 'BarcodedSamplePointer', '__httppacificbiosciences_comPacBioSampleInfo_xsd_CTD_ANON__httppacificbiosciences_comPacBioSampleInfo_xsdBarcodedSamplePointer', True, pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 118, 4), )
+    __BarcodedSamplePointer = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'BarcodedSamplePointer'), 'BarcodedSamplePointer', '__httppacificbiosciences_comPacBioSampleInfo_xsd_CTD_ANON__httppacificbiosciences_comPacBioSampleInfo_xsdBarcodedSamplePointer', True, pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 118, 8), )
 
     
     BarcodedSamplePointer = property(__BarcodedSamplePointer.value, __BarcodedSamplePointer.set, None, 'Pointer to a group of barcoded samples')
@@ -135,7 +138,7 @@ class CTD_ANON_ (pyxb.binding.basis.complexTypeDefinition):
     _AttributeMap.update({
         
     })
-
+_module_typeBindings.CTD_ANON_ = CTD_ANON_
 
 
 # Complex type [anonymous] with content type ELEMENT_ONLY
@@ -145,32 +148,24 @@ class CTD_ANON_2 (pyxb.binding.basis.complexTypeDefinition):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = None
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 130, 2)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 130, 4)
     _ElementMap = {}
     _AttributeMap = {}
     # Base type is pyxb.binding.datatypes.anyType
     
-    # Element {http://pacificbiosciences.com/PacBioSampleInfo.xsd}BioSamplesCsv uses Python identifier BioSamplesCsv
-    __BioSamplesCsv = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'BioSamplesCsv'), 'BioSamplesCsv', '__httppacificbiosciences_comPacBioSampleInfo_xsd_CTD_ANON_2_httppacificbiosciences_comPacBioSampleInfo_xsdBioSamplesCsv', False, pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 137, 4), )
-
-    
-    BioSamplesCsv = property(__BioSamplesCsv.value, __BioSamplesCsv.set, None, 'The name of the biosamples CSV.')
-
-    
     # Element {http://pacificbiosciences.com/PacBioSampleInfo.xsd}BioSample uses Python identifier BioSample
-    __BioSample = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'BioSample'), 'BioSample', '__httppacificbiosciences_comPacBioSampleInfo_xsd_CTD_ANON_2_httppacificbiosciences_comPacBioSampleInfo_xsdBioSample', True, pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 142, 1), )
+    __BioSample = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'BioSample'), 'BioSample', '__httppacificbiosciences_comPacBioSampleInfo_xsd_CTD_ANON_2_httppacificbiosciences_comPacBioSampleInfo_xsdBioSample', True, pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 136, 2), )
 
     
     BioSample = property(__BioSample.value, __BioSample.set, None, 'An individual biological sample.')
 
     _ElementMap.update({
-        __BioSamplesCsv.name() : __BioSamplesCsv,
         __BioSample.name() : __BioSample
     })
     _AttributeMap.update({
         
     })
-
+_module_typeBindings.CTD_ANON_2 = CTD_ANON_2
 
 
 # Complex type {http://pacificbiosciences.com/PacBioSampleInfo.xsd}BioSampleType with content type ELEMENT_ONLY
@@ -180,7 +175,7 @@ class BioSampleType (_ImportedBinding__pbbase.BaseEntityType):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, 'BioSampleType')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 8, 1)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 8, 2)
     _ElementMap = _ImportedBinding__pbbase.BaseEntityType._ElementMap.copy()
     _AttributeMap = _ImportedBinding__pbbase.BaseEntityType._AttributeMap.copy()
     # Base type is _ImportedBinding__pbbase.BaseEntityType
@@ -188,7 +183,7 @@ class BioSampleType (_ImportedBinding__pbbase.BaseEntityType):
     # Element Extensions ({http://pacificbiosciences.com/PacBioBaseDataModel.xsd}Extensions) inherited from {http://pacificbiosciences.com/PacBioBaseDataModel.xsd}BaseEntityType
     
     # Element {http://pacificbiosciences.com/PacBioSampleInfo.xsd}DNABarcodes uses Python identifier DNABarcodes
-    __DNABarcodes = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'DNABarcodes'), 'DNABarcodes', '__httppacificbiosciences_comPacBioSampleInfo_xsd_BioSampleType_httppacificbiosciences_comPacBioSampleInfo_xsdDNABarcodes', False, pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 15, 5), )
+    __DNABarcodes = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'DNABarcodes'), 'DNABarcodes', '__httppacificbiosciences_comPacBioSampleInfo_xsd_BioSampleType_httppacificbiosciences_comPacBioSampleInfo_xsdDNABarcodes', False, pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 15, 10), )
 
     
     DNABarcodes = property(__DNABarcodes.value, __DNABarcodes.set, None, 'A list of barcodes associated with the biological sample')
@@ -212,88 +207,88 @@ class BioSampleType (_ImportedBinding__pbbase.BaseEntityType):
     
     # Attribute DateReceived uses Python identifier DateReceived
     __DateReceived = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'DateReceived'), 'DateReceived', '__httppacificbiosciences_comPacBioSampleInfo_xsd_BioSampleType_DateReceived', pyxb.binding.datatypes.dateTime)
-    __DateReceived._DeclarationLocation = pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 34, 4)
-    __DateReceived._UseLocation = pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 34, 4)
+    __DateReceived._DeclarationLocation = pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 34, 8)
+    __DateReceived._UseLocation = pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 34, 8)
     
     DateReceived = property(__DateReceived.value, __DateReceived.set, None, 'Date the sample was received by the lab')
 
     
     # Attribute Organism uses Python identifier Organism
     __Organism = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'Organism'), 'Organism', '__httppacificbiosciences_comPacBioSampleInfo_xsd_BioSampleType_Organism', pyxb.binding.datatypes.string)
-    __Organism._DeclarationLocation = pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 39, 4)
-    __Organism._UseLocation = pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 39, 4)
+    __Organism._DeclarationLocation = pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 39, 8)
+    __Organism._UseLocation = pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 39, 8)
     
     Organism = property(__Organism.value, __Organism.set, None, 'e.g. HIV, E.coli')
 
     
     # Attribute Reference uses Python identifier Reference
     __Reference = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'Reference'), 'Reference', '__httppacificbiosciences_comPacBioSampleInfo_xsd_BioSampleType_Reference', pyxb.binding.datatypes.string)
-    __Reference._DeclarationLocation = pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 44, 4)
-    __Reference._UseLocation = pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 44, 4)
+    __Reference._DeclarationLocation = pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 44, 8)
+    __Reference._UseLocation = pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 44, 8)
     
     Reference = property(__Reference.value, __Reference.set, None, 'Name of reference, or pointer to one at e.g. NCBI RefSeq')
 
     
     # Attribute DNAType uses Python identifier DNAType
     __DNAType = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'DNAType'), 'DNAType', '__httppacificbiosciences_comPacBioSampleInfo_xsd_BioSampleType_DNAType', pyxb.binding.datatypes.string)
-    __DNAType._DeclarationLocation = pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 49, 4)
-    __DNAType._UseLocation = pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 49, 4)
+    __DNAType._DeclarationLocation = pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 49, 8)
+    __DNAType._UseLocation = pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 49, 8)
     
     DNAType = property(__DNAType.value, __DNAType.set, None, 'shotgun library, amplicon, etc.')
 
     
     # Attribute Concentration uses Python identifier Concentration
     __Concentration = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'Concentration'), 'Concentration', '__httppacificbiosciences_comPacBioSampleInfo_xsd_BioSampleType_Concentration', pyxb.binding.datatypes.float)
-    __Concentration._DeclarationLocation = pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 54, 4)
-    __Concentration._UseLocation = pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 54, 4)
+    __Concentration._DeclarationLocation = pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 54, 8)
+    __Concentration._UseLocation = pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 54, 8)
     
     Concentration = property(__Concentration.value, __Concentration.set, None, 'in ng/uL, e.g. 250')
 
     
     # Attribute QuantificationMethod uses Python identifier QuantificationMethod
     __QuantificationMethod = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'QuantificationMethod'), 'QuantificationMethod', '__httppacificbiosciences_comPacBioSampleInfo_xsd_BioSampleType_QuantificationMethod', pyxb.binding.datatypes.string)
-    __QuantificationMethod._DeclarationLocation = pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 59, 4)
-    __QuantificationMethod._UseLocation = pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 59, 4)
+    __QuantificationMethod._DeclarationLocation = pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 59, 8)
+    __QuantificationMethod._UseLocation = pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 59, 8)
     
     QuantificationMethod = property(__QuantificationMethod.value, __QuantificationMethod.set, None, 'e.g. Qubit')
 
     
     # Attribute SMRTBellConcentration uses Python identifier SMRTBellConcentration
     __SMRTBellConcentration = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'SMRTBellConcentration'), 'SMRTBellConcentration', '__httppacificbiosciences_comPacBioSampleInfo_xsd_BioSampleType_SMRTBellConcentration', pyxb.binding.datatypes.float)
-    __SMRTBellConcentration._DeclarationLocation = pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 64, 4)
-    __SMRTBellConcentration._UseLocation = pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 64, 4)
+    __SMRTBellConcentration._DeclarationLocation = pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 64, 8)
+    __SMRTBellConcentration._UseLocation = pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 64, 8)
     
     SMRTBellConcentration = property(__SMRTBellConcentration.value, __SMRTBellConcentration.set, None, 'in ng/uL, e.g. 4.5')
 
     
     # Attribute SMRTBellQuantificationMethod uses Python identifier SMRTBellQuantificationMethod
     __SMRTBellQuantificationMethod = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'SMRTBellQuantificationMethod'), 'SMRTBellQuantificationMethod', '__httppacificbiosciences_comPacBioSampleInfo_xsd_BioSampleType_SMRTBellQuantificationMethod', pyxb.binding.datatypes.string)
-    __SMRTBellQuantificationMethod._DeclarationLocation = pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 69, 4)
-    __SMRTBellQuantificationMethod._UseLocation = pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 69, 4)
+    __SMRTBellQuantificationMethod._DeclarationLocation = pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 69, 8)
+    __SMRTBellQuantificationMethod._UseLocation = pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 69, 8)
     
     SMRTBellQuantificationMethod = property(__SMRTBellQuantificationMethod.value, __SMRTBellQuantificationMethod.set, None, 'e.g. Qubit')
 
     
     # Attribute BufferName uses Python identifier BufferName
     __BufferName = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'BufferName'), 'BufferName', '__httppacificbiosciences_comPacBioSampleInfo_xsd_BioSampleType_BufferName', pyxb.binding.datatypes.string)
-    __BufferName._DeclarationLocation = pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 74, 4)
-    __BufferName._UseLocation = pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 74, 4)
+    __BufferName._DeclarationLocation = pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 74, 8)
+    __BufferName._UseLocation = pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 74, 8)
     
     BufferName = property(__BufferName.value, __BufferName.set, None, 'e.g. Tris HCl')
 
     
     # Attribute SamplePrepKit uses Python identifier SamplePrepKit
     __SamplePrepKit = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'SamplePrepKit'), 'SamplePrepKit', '__httppacificbiosciences_comPacBioSampleInfo_xsd_BioSampleType_SamplePrepKit', pyxb.binding.datatypes.string)
-    __SamplePrepKit._DeclarationLocation = pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 79, 4)
-    __SamplePrepKit._UseLocation = pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 79, 4)
+    __SamplePrepKit._DeclarationLocation = pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 79, 8)
+    __SamplePrepKit._UseLocation = pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 79, 8)
     
     SamplePrepKit = property(__SamplePrepKit.value, __SamplePrepKit.set, None, 'e.g. SMRTbell Template Prep Kit')
 
     
     # Attribute TargetLibrarySize uses Python identifier TargetLibrarySize
     __TargetLibrarySize = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, 'TargetLibrarySize'), 'TargetLibrarySize', '__httppacificbiosciences_comPacBioSampleInfo_xsd_BioSampleType_TargetLibrarySize', pyxb.binding.datatypes.string)
-    __TargetLibrarySize._DeclarationLocation = pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 84, 4)
-    __TargetLibrarySize._UseLocation = pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 84, 4)
+    __TargetLibrarySize._DeclarationLocation = pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 84, 8)
+    __TargetLibrarySize._UseLocation = pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 84, 8)
     
     TargetLibrarySize = property(__TargetLibrarySize.value, __TargetLibrarySize.set, None, '2000, 10000, 20000')
 
@@ -313,6 +308,7 @@ class BioSampleType (_ImportedBinding__pbbase.BaseEntityType):
         __SamplePrepKit.name() : __SamplePrepKit,
         __TargetLibrarySize.name() : __TargetLibrarySize
     })
+_module_typeBindings.BioSampleType = BioSampleType
 Namespace.addCategoryObject('typeBinding', 'BioSampleType', BioSampleType)
 
 
@@ -323,7 +319,7 @@ class CTD_ANON_3 (_ImportedBinding__pbbase.BaseEntityType):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = None
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 19, 6)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 19, 12)
     _ElementMap = _ImportedBinding__pbbase.BaseEntityType._ElementMap.copy()
     _AttributeMap = _ImportedBinding__pbbase.BaseEntityType._AttributeMap.copy()
     # Base type is _ImportedBinding__pbbase.BaseEntityType
@@ -331,7 +327,7 @@ class CTD_ANON_3 (_ImportedBinding__pbbase.BaseEntityType):
     # Element Extensions ({http://pacificbiosciences.com/PacBioBaseDataModel.xsd}Extensions) inherited from {http://pacificbiosciences.com/PacBioBaseDataModel.xsd}BaseEntityType
     
     # Element {http://pacificbiosciences.com/PacBioSampleInfo.xsd}DNABarcode uses Python identifier DNABarcode
-    __DNABarcode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'DNABarcode'), 'DNABarcode', '__httppacificbiosciences_comPacBioSampleInfo_xsd_CTD_ANON_3_httppacificbiosciences_comPacBioSampleInfo_xsdDNABarcode', True, pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 23, 10), )
+    __DNABarcode = pyxb.binding.content.ElementDeclaration(pyxb.namespace.ExpandedName(Namespace, 'DNABarcode'), 'DNABarcode', '__httppacificbiosciences_comPacBioSampleInfo_xsd_CTD_ANON_3_httppacificbiosciences_comPacBioSampleInfo_xsdDNABarcode', True, pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 23, 20), )
 
     
     DNABarcode = property(__DNABarcode.value, __DNABarcode.set, None, 'A sequence of barcodes associated with the biological sample')
@@ -358,29 +354,26 @@ class CTD_ANON_3 (_ImportedBinding__pbbase.BaseEntityType):
     _AttributeMap.update({
         
     })
+_module_typeBindings.CTD_ANON_3 = CTD_ANON_3
 
 
-
-BioSamplePointers = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'BioSamplePointers'), CTD_ANON, documentation='Back references to other BarcodedSampleType object UniqueIds which utilize this sample', location=pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 92, 1))
+BioSamplePointers = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'BioSamplePointers'), CTD_ANON, documentation='Back references to other BarcodedSampleType object UniqueIds which utilize this sample', location=pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 92, 2))
 Namespace.addCategoryObject('elementBinding', BioSamplePointers.name().localName(), BioSamplePointers)
 
-BarcodedSamplePointers = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'BarcodedSamplePointers'), CTD_ANON_, documentation='Back references to other BarcodedSampleType object UniqueIds which utilize this sample', location=pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 112, 1))
+BarcodedSamplePointers = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'BarcodedSamplePointers'), CTD_ANON_, documentation='Back references to other BarcodedSampleType object UniqueIds which utilize this sample', location=pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 112, 2))
 Namespace.addCategoryObject('elementBinding', BarcodedSamplePointers.name().localName(), BarcodedSamplePointers)
 
-BioSamples = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'BioSamples'), CTD_ANON_2, documentation='List of biological samples.', location=pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 126, 1))
+BioSamples = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'BioSamples'), CTD_ANON_2, documentation='List of biological samples.', location=pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 126, 2))
 Namespace.addCategoryObject('elementBinding', BioSamples.name().localName(), BioSamples)
 
-BioSample = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'BioSample'), BioSampleType, documentation='An individual biological sample.', location=pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 142, 1))
+BioSample = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'BioSample'), BioSampleType, documentation='An individual biological sample.', location=pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 136, 2))
 Namespace.addCategoryObject('elementBinding', BioSample.name().localName(), BioSample)
 
-BioSamplesCsv = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'BioSamplesCsv'), _ImportedBinding__pbbase.InputOutputDataType, documentation='The name of the biosamples CSV.', location=pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 137, 4))
-Namespace.addCategoryObject('elementBinding', BioSamplesCsv.name().localName(), BioSamplesCsv)
 
 
+CTD_ANON._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'BioSamplePointer'), pyxb.binding.datatypes.IDREF, scope=CTD_ANON, documentation='Pointer to a single biological sample', location=pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 103, 10)))
 
-CTD_ANON._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'BioSamplePointer'), pyxb.binding.datatypes.IDREF, scope=CTD_ANON, documentation='Pointer to a single biological sample', location=pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 103, 5)))
-
-CTD_ANON._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'BarcodedSamplePointers'), CTD_ANON_, scope=CTD_ANON, documentation='Back references to other BarcodedSampleType object UniqueIds which utilize this sample', location=pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 112, 1)))
+CTD_ANON._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'BarcodedSamplePointers'), CTD_ANON_, scope=CTD_ANON, documentation='Back references to other BarcodedSampleType object UniqueIds which utilize this sample', location=pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 112, 2)))
 
 def _BuildAutomaton ():
     # Remove this helper function from the namespace after it is invoked
@@ -391,11 +384,11 @@ def _BuildAutomaton ():
     counters = set()
     states = []
     final_update = set()
-    symbol = pyxb.binding.content.ElementUse(CTD_ANON._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'BarcodedSamplePointers')), pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 102, 5))
+    symbol = pyxb.binding.content.ElementUse(CTD_ANON._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'BarcodedSamplePointers')), pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 102, 10))
     st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_0)
     final_update = set()
-    symbol = pyxb.binding.content.ElementUse(CTD_ANON._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'BioSamplePointer')), pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 103, 5))
+    symbol = pyxb.binding.content.ElementUse(CTD_ANON._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'BioSamplePointer')), pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 103, 10))
     st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_1)
     transitions = []
@@ -408,7 +401,7 @@ CTD_ANON._Automaton = _BuildAutomaton()
 
 
 
-CTD_ANON_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'BarcodedSamplePointer'), pyxb.binding.datatypes.IDREF, scope=CTD_ANON_, documentation='Pointer to a group of barcoded samples', location=pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 118, 4)))
+CTD_ANON_._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'BarcodedSamplePointer'), pyxb.binding.datatypes.IDREF, scope=CTD_ANON_, documentation='Pointer to a group of barcoded samples', location=pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 118, 8)))
 
 def _BuildAutomaton_ ():
     # Remove this helper function from the namespace after it is invoked
@@ -419,7 +412,7 @@ def _BuildAutomaton_ ():
     counters = set()
     states = []
     final_update = set()
-    symbol = pyxb.binding.content.ElementUse(CTD_ANON_._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'BarcodedSamplePointer')), pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 118, 4))
+    symbol = pyxb.binding.content.ElementUse(CTD_ANON_._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'BarcodedSamplePointer')), pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 118, 8))
     st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_0)
     transitions = []
@@ -432,9 +425,7 @@ CTD_ANON_._Automaton = _BuildAutomaton_()
 
 
 
-CTD_ANON_2._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'BioSamplesCsv'), _ImportedBinding__pbbase.InputOutputDataType, scope=CTD_ANON_2, documentation='The name of the biosamples CSV.', location=pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 137, 4)))
-
-CTD_ANON_2._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'BioSample'), BioSampleType, scope=CTD_ANON_2, documentation='An individual biological sample.', location=pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 142, 1)))
+CTD_ANON_2._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'BioSample'), BioSampleType, scope=CTD_ANON_2, documentation='An individual biological sample.', location=pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 136, 2)))
 
 def _BuildAutomaton_2 ():
     # Remove this helper function from the namespace after it is invoked
@@ -443,34 +434,22 @@ def _BuildAutomaton_2 ():
     import pyxb.utils.fac as fac
 
     counters = set()
-    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 132, 16))
-    counters.add(cc_0)
     states = []
-    final_update = None
-    symbol = pyxb.binding.content.ElementUse(CTD_ANON_2._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'BioSamplesCsv')), pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 132, 16))
+    final_update = set()
+    symbol = pyxb.binding.content.ElementUse(CTD_ANON_2._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'BioSample')), pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 132, 8))
     st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_0)
-    final_update = set()
-    symbol = pyxb.binding.content.ElementUse(CTD_ANON_2._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'BioSample')), pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 133, 4))
-    st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
-    states.append(st_1)
     transitions = []
     transitions.append(fac.Transition(st_0, [
-        fac.UpdateInstruction(cc_0, True) ]))
-    transitions.append(fac.Transition(st_1, [
-        fac.UpdateInstruction(cc_0, False) ]))
-    st_0._set_transitionSet(transitions)
-    transitions = []
-    transitions.append(fac.Transition(st_1, [
          ]))
-    st_1._set_transitionSet(transitions)
+    st_0._set_transitionSet(transitions)
     return fac.Automaton(states, counters, False, containing_state=None)
 CTD_ANON_2._Automaton = _BuildAutomaton_2()
 
 
 
 
-BioSampleType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'DNABarcodes'), CTD_ANON_3, scope=BioSampleType, documentation='A list of barcodes associated with the biological sample', location=pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 15, 5)))
+BioSampleType._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'DNABarcodes'), CTD_ANON_3, scope=BioSampleType, documentation='A list of barcodes associated with the biological sample', location=pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 15, 10)))
 
 def _BuildAutomaton_3 ():
     # Remove this helper function from the namespace after it is invoked
@@ -479,19 +458,19 @@ def _BuildAutomaton_3 ():
     import pyxb.utils.fac as fac
 
     counters = set()
-    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioBaseDataModel.xsd', 98, 3))
+    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioBaseDataModel.xsd', 98, 6))
     counters.add(cc_0)
-    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 15, 5))
+    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 15, 10))
     counters.add(cc_1)
     states = []
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_0, False))
-    symbol = pyxb.binding.content.ElementUse(BioSampleType._UseForTag(pyxb.namespace.ExpandedName(_Namespace_pbbase, 'Extensions')), pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioBaseDataModel.xsd', 98, 3))
+    symbol = pyxb.binding.content.ElementUse(BioSampleType._UseForTag(pyxb.namespace.ExpandedName(_Namespace_pbbase, 'Extensions')), pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioBaseDataModel.xsd', 98, 6))
     st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_0)
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_1, False))
-    symbol = pyxb.binding.content.ElementUse(BioSampleType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'DNABarcodes')), pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 15, 5))
+    symbol = pyxb.binding.content.ElementUse(BioSampleType._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'DNABarcodes')), pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 15, 10))
     st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_1)
     transitions = []
@@ -510,7 +489,7 @@ BioSampleType._Automaton = _BuildAutomaton_3()
 
 
 
-CTD_ANON_3._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'DNABarcode'), _ImportedBinding__pbbase.DNABarcode, scope=CTD_ANON_3, documentation='A sequence of barcodes associated with the biological sample', location=pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 23, 10)))
+CTD_ANON_3._AddElement(pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, 'DNABarcode'), _ImportedBinding__pbbase.DNABarcode, scope=CTD_ANON_3, documentation='A sequence of barcodes associated with the biological sample', location=pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 23, 20)))
 
 def _BuildAutomaton_4 ():
     # Remove this helper function from the namespace after it is invoked
@@ -519,23 +498,23 @@ def _BuildAutomaton_4 ():
     import pyxb.utils.fac as fac
 
     counters = set()
-    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 19, 6))
+    cc_0 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 19, 12))
     counters.add(cc_0)
-    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioBaseDataModel.xsd', 98, 3))
+    cc_1 = fac.CounterCondition(min=0, max=1, metadata=pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioBaseDataModel.xsd', 98, 6))
     counters.add(cc_1)
-    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 23, 10))
+    cc_2 = fac.CounterCondition(min=0, max=None, metadata=pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 23, 20))
     counters.add(cc_2)
     states = []
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_0, False))
     final_update.add(fac.UpdateInstruction(cc_1, False))
-    symbol = pyxb.binding.content.ElementUse(CTD_ANON_3._UseForTag(pyxb.namespace.ExpandedName(_Namespace_pbbase, 'Extensions')), pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioBaseDataModel.xsd', 98, 3))
+    symbol = pyxb.binding.content.ElementUse(CTD_ANON_3._UseForTag(pyxb.namespace.ExpandedName(_Namespace_pbbase, 'Extensions')), pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioBaseDataModel.xsd', 98, 6))
     st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_0)
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_0, False))
     final_update.add(fac.UpdateInstruction(cc_2, False))
-    symbol = pyxb.binding.content.ElementUse(CTD_ANON_3._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'DNABarcode')), pyxb.utils.utility.Location('/tmp/tmpcx2T3Lxsds/PacBioSampleInfo.xsd', 23, 10))
+    symbol = pyxb.binding.content.ElementUse(CTD_ANON_3._UseForTag(pyxb.namespace.ExpandedName(Namespace, 'DNABarcode')), pyxb.utils.utility.Location('/tmp/tmpqwf3af3mxsds/PacBioSampleInfo.xsd', 23, 20))
     st_1 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_1)
     transitions = []
